@@ -15,7 +15,7 @@ pub(crate) struct Environment {
   pub(crate) working_directory: PathBuf,
   pub(crate) stderr: Stderr,
   #[cfg(test)]
-  _working_directory_tempdir: TempDir,
+  pub(crate) working_directory_tempdir: TempDir,
 }
 
 impl Environment {
@@ -25,7 +25,7 @@ impl Environment {
       stderr: Stderr::production(),
       working_directory: env::current_dir().context(error::CurrentDir)?,
       #[cfg(test)]
-      _working_directory_tempdir: TempDir::new().unwrap(),
+      working_directory_tempdir: TempDir::new().unwrap(),
     })
   }
 
@@ -44,7 +44,7 @@ impl Environment {
         .collect(),
       stderr: Stderr::test(),
       working_directory: tempdir.path().to_owned(),
-      _working_directory_tempdir: tempdir,
+      working_directory_tempdir: tempdir,
     }
   }
 
